==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/web/PostCss.java <==
package io.github.cdklabs.projen.web;

/**
 * (experimental) Declares a PostCSS dependency with a default config file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:29.022Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.PostCss")
public class PostCss extends software.amazon.jsii.JsiiObject {

    protected PostCss(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PostCss(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PostCss(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.web.PostCssOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PostCss(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.JsonFile getFile() {
        return software.amazon.jsii.Kernel.get(this, "file", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.JsonFile.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFileName() {
        return software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.web.TailwindConfig getTailwind() {
        return software.amazon.jsii.Kernel.get(this, "tailwind", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.web.TailwindConfig.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.web.PostCss}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.web.PostCss> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private io.github.cdklabs.projen.web.PostCssOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
        }

        /**
         * Default: "postcss.config.json"
         * <p>
         * @return {@code this}
         * @param fileName This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileName(final java.lang.String fileName) {
            this.options().fileName(fileName);
            return this;
        }

        /**
         * (experimental) Install Tailwind CSS as a PostCSS plugin.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param tailwind Install Tailwind CSS as a PostCSS plugin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwind(final java.lang.Boolean tailwind) {
            this.options().tailwind(tailwind);
            return this;
        }

        /**
         * (experimental) Tailwind CSS options.
         * <p>
         * @return {@code this}
         * @param tailwindOptions Tailwind CSS options. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwindOptions(final io.github.cdklabs.projen.web.TailwindConfigOptions tailwindOptions) {
            this.options().tailwindOptions(tailwindOptions);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.web.PostCss}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.web.PostCss build() {
            return new io.github.cdklabs.projen.web.PostCss(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.web.PostCssOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.web.PostCssOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/web/PostCss.java <==
package io.github.cdklabs.projen.web;

/**
 * (experimental) Declares a PostCSS dependency with a default config file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.727Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.PostCss")
public class PostCss extends software.amazon.jsii.JsiiObject {

    protected PostCss(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PostCss(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PostCss(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.web.PostCssOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PostCss(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.JsonFile getFile() {
        return software.amazon.jsii.Kernel.get(this, "file", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.JsonFile.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFileName() {
        return software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.web.TailwindConfig getTailwind() {
        return software.amazon.jsii.Kernel.get(this, "tailwind", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.web.TailwindConfig.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.web.PostCss}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.web.PostCss> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private io.github.cdklabs.projen.web.PostCssOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
        }

        /**
         * Default: "postcss.config.json"
         * <p>
         * @return {@code this}
         * @param fileName This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileName(final java.lang.String fileName) {
            this.options().fileName(fileName);
            return this;
        }

        /**
         * (experimental) Install Tailwind CSS as a PostCSS plugin.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param tailwind Install Tailwind CSS as a PostCSS plugin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwind(final java.lang.Boolean tailwind) {
            this.options().tailwind(tailwind);
            return this;
        }

        /**
         * (experimental) Tailwind CSS options.
         * <p>
         * @return {@code this}
         * @param tailwindOptions Tailwind CSS options. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwindOptions(final io.github.cdklabs.projen.web.TailwindConfigOptions tailwindOptions) {
            this.options().tailwindOptions(tailwindOptions);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.web.PostCss}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.web.PostCss build() {
            return new io.github.cdklabs.projen.web.PostCss(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.web.PostCssOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.web.PostCssOptions.Builder();
            }
            return this.options;
        }
    }
}
